@@ -6,7 +6,7 @@ use Pcore;
 use Pcore::GeoIP;
 
 # update GeoIP
-P->geoip->update_all;
+P->geoip->update_all or exit 3;
 
 1;
 __END__
